==> jammo_0.1.36.tar.gz: jammo-0.1.36/src/chum/welcome.c <==
/*
 * welcome.c
 *
 * This file is part of JamMo.
 *
 * (c) 2009-2010 University of Oulu
 *
 * Authors: Aapo Rantalainen
 */
#include "../meam/jammo-sample.h"
#include "../chum/chum.h"  //DATA_DIR
#include <tangle.h>
#include <clutter/clutter.h>


//FIXME: how to react only first time when on_transition_completed?
static gboolean done=FALSE;
static void on_transition_completed(TangleActor *actor, ClutterActorBox *arg1, ClutterActorBox *arg2, gpointer user_data) {
	if (!(done)){
		ClutterActor* new_parent =  jammo_get_actor_by_id("main-menu-view");
		g_return_if_fail(new_parent != NULL);

		/*
		ClutterActor *temp_bear=mentor_give_temp_bear();
		clutter_container_add_actor (CLUTTER_CONTAINER (new_parent), temp_bear);

		mentor_speech(temp_bear,"mentor_speech/mentor_01_fi.ogg");
*/
		done=TRUE;
	}
}

static void finalize_welcome(void){
	ClutterActor* actor;

	//just be sure, that there aren't any sounds when going next view
	jammo_sample_stop_all();

	if ((actor = jammo_get_actor_by_id("welcome-view"))) {
		tangle_actor_hide_animated(TANGLE_ACTOR(actor));
		g_signal_connect(actor, "transition-completed", G_CALLBACK(on_transition_completed), NULL);
	}
	if ((actor = jammo_get_actor_by_id("main-menu-view"))) {
		clutter_actor_show(actor);
		clutter_actor_queue_relayout(clutter_actor_get_parent(actor));
	}

}

void welcome_door_clicked(TangleAction *action, GObject *source, const gchar *trigger, TangleProperties *properties){
	ClutterActor* actor;
	ClutterAnimation* animation;
	gchar* filename;
	JammoSample* sample;

	actor = jammo_get_actor_by_id("welcome-door");
	g_assert(actor != NULL);
	
	if ((animation = clutter_actor_get_animation(actor))) {
		clutter_animation_completed(animation);
	} else {
		animation = clutter_actor_animate(actor, CLUTTER_LINEAR, 2750, "rotation-angle-y", -110.0, NULL);
		g_signal_connect(animation, "completed", G_CALLBACK(finalize_welcome), NULL);
		
		filename = g_strdup_printf("%s/door_opening.wav",DATA_DIR);
		sample = jammo_sample_new_from_file(filename);
		g_free(filename);
		jammo_sample_play(sample);
		g_object_unref(sample);
	}


}

==> jammo_0.1.38.tar.gz: jammo-0.1.38/src/chum/welcome.c <==
/*
 * welcome.c
 *
 * This file is part of JamMo.
 *
 * (c) 2009-2010 University of Oulu
 *
 * Authors: Aapo Rantalainen
 */
#include "../meam/jammo-sample.h"
#include "../chum/chum.h"  //DATA_DIR
#include <tangle.h>
#include <clutter/clutter.h>
#include "jammo-mentor.h"

static void on_transition_completed(TangleActor *actor, ClutterActorBox *arg1, ClutterActorBox *arg2, gpointer user_data) {
	jammo_mentor_speak_once(jammo_mentor_get_default(),  "/opt/jammo/mentor_speech/mentor_main_menu_welcome_fi.ogg");
	jammo_mentor_set_idle_speech(jammo_mentor_get_default(), "/opt/jammo/mentor_speech/mentor_main_menu_idle_fi.ogg");
}

static void finalize_welcome(void){
	ClutterActor* actor;

	//just be sure, that there aren't any sounds when going next view
	jammo_sample_stop_all();

	if ((actor = jammo_get_actor_by_id("welcome-view"))) {
		tangle_actor_hide_animated(TANGLE_ACTOR(actor));
		g_signal_connect(actor, "transition-completed", G_CALLBACK(on_transition_completed), NULL);
	}
	if ((actor = jammo_get_actor_by_id("main-menu-view"))) {
		clutter_actor_show(actor);
		clutter_actor_queue_relayout(clutter_actor_get_parent(actor));
	}

}

void welcome_door_clicked(TangleAction *action, GObject *source, const gchar *trigger, TangleProperties *properties){
	ClutterActor* actor;
	ClutterAnimation* animation;
	gchar* filename;
	JammoSample* sample;

	actor = jammo_get_actor_by_id("welcome-door");
	g_assert(actor != NULL);
	
	if ((animation = clutter_actor_get_animation(actor))) {
		clutter_animation_completed(animation);
	} else {
		animation = clutter_actor_animate(actor, CLUTTER_LINEAR, 2750, "rotation-angle-y", -110.0, NULL);
		g_signal_connect(animation, "completed", G_CALLBACK(finalize_welcome), NULL);
		
		filename = g_strdup_printf("%s/door_opening.wav",DATA_DIR);
		sample = jammo_sample_new_from_file(filename);
		g_free(filename);
		jammo_sample_play(sample);
		g_object_unref(sample);
	}

	//Show version number: defined in configure.ac
	gchar* version = g_strdup_printf("JamMo version:%s",VERSION);
	ClutterActor* version_label = clutter_text_new_with_text ("Luxi Mono 8",version); 
	g_free(version);
	actor = jammo_get_actor_by_id("welcome-view");
	clutter_container_add_actor (CLUTTER_CONTAINER (actor), version_label);

}
